#####################################################
# dbcore.pm
#
# These are the "core" routines for access to the
# mySQL database.
#
# Neither DBI nor mySQL is mentioned anywhere else.
# The SQL that occurs in other files may be portable.
# If so, only this routine needs to change for
# PostgreSQL or Oracle.
#
# See COPYING for licensing information.
#
# Written by:
#
#   Creighton MacDonnell
#   http://macdonnell.ca/
#
#####################################################

# Perl modules
use strict;
use DBD::mysql;

# global variables
use vars qw($conf $dbh $dbconnected);

$dbconnected = '';

#############################################################
# connect to database
#############################################################
sub dbconnect {

  # allow persistance?
  return
    if $dbh and
       $$conf{'persistance'} and
       $$conf{'persistance'} eq 'YES';

  # Name of GnuDIP (mySQL) database
  my $gnudipdatabase = $$conf{'gnudipdatabase'};

  # User name to connect to the database
  my $gnudipuser = $$conf{'gnudipuser'};

  # Password to connect to the database
  my $gnudippass = $$conf{'gnudippassword'};

  # Host where the database server resides
  my $gnudipserver = $$conf{'gnudipserver'};

  $gnudipdatabase = '' if !defined($gnudipdatabase);
  $gnudipuser     = '' if !defined($gnudipuser);
  $gnudippass     = '' if !defined($gnudippass);
  $gnudipserver   = '' if !defined($gnudipserver);

  # connect to database
  $dbh = DBI->connect(
    "DBI:mysql:$gnudipdatabase:$gnudipserver",
    $gnudipuser,
    $gnudippass
    );
  if (!$dbh) {
    my $str = $DBI::errstr;
    writelog('Could not connect to mySQL database:');
    writelog("  $str");
    dberror();
  }
}

#############################################################
# execute an SQL statement and catch errors
#############################################################
sub dbexecute {
  my $statement = shift;

  if (! $dbconnected) {
    dbconnect();
    $dbconnected = 1;
  }

  my $sth = $dbh->prepare($statement);
  if (!$sth) {
    my $str = $DBI::errstr;
    writelog('Could not prepare SQL statement:');
    writelog("  $str");
    dberror();
  }

  my $rc = $sth->execute;
  if (!$rc) {
    my $str = $DBI::errstr;
    writelog('Could not execute SQL statement:');
    writelog("  $str");
    dberror();
  }

  return $sth;
}

#####################################################
# must return 1
#####################################################
1;

